You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tamaya.apache.org by an...@apache.org on 2018/11/18 21:20:39 UTC

[06/16] incubator-tamaya-sandbox git commit: TAMAYA-274 Reduced API footprint by using Java 8 features. Added some lambdas. TAMAYA-355 Enable mapping of lists and arrays into internal datastructures. TAMAYA-353 Adding support for different classloader

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/management/src/test/java/org/apache/tamaya/management/internal/ManagedConfigTest.java
----------------------------------------------------------------------
diff --git a/management/src/test/java/org/apache/tamaya/management/internal/ManagedConfigTest.java b/management/src/test/java/org/apache/tamaya/management/internal/ManagedConfigTest.java
index 90ad0bf..5cbef7f 100644
--- a/management/src/test/java/org/apache/tamaya/management/internal/ManagedConfigTest.java
+++ b/management/src/test/java/org/apache/tamaya/management/internal/ManagedConfigTest.java
@@ -100,7 +100,7 @@ public class ManagedConfigTest {
     public void testRegisterMBean() throws Exception {
         ObjectName on = ConfigManagementSupport.registerMBean();
         ConfigManagementSupport.registerMBean();
-        // Lookup object name
+        // Lookup createObject name
         MBeanServer mbs = ManagementFactory.getPlatformMBeanServer();
         assertTrue(mbs.getMBeanInfo(on)!=null);
     }
@@ -110,7 +110,7 @@ public class ManagedConfigTest {
         ObjectName on1 = ConfigManagementSupport.registerMBean("SubContext1");
         ConfigManagementSupport.registerMBean("SubContext1");
         ObjectName on2 = ConfigManagementSupport.registerMBean("SubContext2");
-        // Lookup object name
+        // Lookup createObject name
         MBeanServer mbs = ManagementFactory.getPlatformMBeanServer();
         assertTrue(mbs.getMBeanInfo(on1)!=null);
         assertTrue(mbs.getMBeanInfo(on2)!=null);

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/CachedFilter.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/CachedFilter.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/CachedFilter.java
index f72e6ae..52e92c4 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/CachedFilter.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/CachedFilter.java
@@ -27,7 +27,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.TimeUnit;
 
 /**
- * Simple filter that never changes a key/value pair returned, regardless if a value
+ * Simple filter that never changes a key/createValue pair returned, regardless if a createValue
  * is changing underneath, hereby different values for single and multi-property access
  * are considered.
  */
@@ -78,7 +78,7 @@ public class CachedFilter implements PropertyFilter{
     }
 
     /**
-     * Method checks for a cached value. if present and valid the cached value is returned.
+     * Method checks for a cached createValue. if present and valid the cached createValue is returned.
      * If not valid the cached entry is removed/updated.
      * @param value
      * @return

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/Enabled.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/Enabled.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/Enabled.java
index b3051d3..325926e 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/Enabled.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/Enabled.java
@@ -25,13 +25,13 @@ public interface Enabled {
 
     /**
      * Returns the enabled property.
-     * @return the enabled value.
+     * @return the enabled createValue.
      */
     boolean isEnabled();
 
     /**
      * Enables/disables this property source.
-     * @param enabled the enabled value.
+     * @param enabled the enabled createValue.
      */
     void setEnabled(boolean enabled);
 }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/EnabledPropertySource.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/EnabledPropertySource.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/EnabledPropertySource.java
index 3eafd38..7ccb504 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/EnabledPropertySource.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/EnabledPropertySource.java
@@ -61,7 +61,7 @@ public final class EnabledPropertySource
 
     /**
      * Returns the enabled property.
-     * @return the enabled value.
+     * @return the enabled createValue.
      */
     @Override
     public boolean isEnabled(){
@@ -70,7 +70,7 @@ public final class EnabledPropertySource
 
     /**
      * Enables/disables this property source.
-     * @param enabled the enabled value.
+     * @param enabled the enabled createValue.
      */
     @Override
     public void setEnabled(boolean enabled){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/HideFilter.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/HideFilter.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/HideFilter.java
index 5b6198b..431b72e 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/HideFilter.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/HideFilter.java
@@ -25,7 +25,7 @@ import org.apache.tamaya.spi.PropertyFilter;
 import org.apache.tamaya.spi.PropertyValue;
 
 /**
- * Simple filter that never changes a key/value pair returned, regardless if a value
+ * Simple filter that never changes a key/createValue pair returned, regardless if a createValue
  * is changing underneath, hereby different values for single and multi-property access
  * are considered.
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/ImmutableFilter.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/ImmutableFilter.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/ImmutableFilter.java
index 2658fd4..0b957a3 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/ImmutableFilter.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/ImmutableFilter.java
@@ -27,7 +27,7 @@ import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 
 /**
- * Simple filter that never changes a key/value pair returned, regardless if a value
+ * Simple filter that never changes a key/createValue pair returned, regardless if a createValue
  * is changing underneath, hereby different values for single and multi-property access
  * are considered.
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/MapFilter.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/MapFilter.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/MapFilter.java
index c2b5bc7..f7ed5a7 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/MapFilter.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/MapFilter.java
@@ -25,7 +25,7 @@ import org.apache.tamaya.spi.PropertyValue;
 import java.util.Map;
 
 /**
- * Simple filter that never changes a key/value pair returned, regardless if a value
+ * Simple filter that never changes a key/createValue pair returned, regardless if a createValue
  * is changing underneath, hereby different values for single and multi-property access
  * are considered.
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/MaskFilter.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/MaskFilter.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/MaskFilter.java
index b472f2f..cb63a25 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/MaskFilter.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/MaskFilter.java
@@ -28,7 +28,7 @@ import java.util.List;
 import java.util.Map;
 
 /**
- * Simple filter that never changes a key/value pair returned, regardless if a value
+ * Simple filter that never changes a key/createValue pair returned, regardless if a createValue
  * is changing underneath, hereby different values for single and multi-property access
  * are considered.
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/MetaContext.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/MetaContext.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/MetaContext.java
index 2509dda..a46ead1 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/MetaContext.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/MetaContext.java
@@ -113,7 +113,7 @@ public final class MetaContext {
     /**
      * Access the given context property.
      * @param key the key, not null
-     * @return the value, or null.
+     * @return the createValue, or null.
      */
     public String getProperty(String key){
         return getProperty(key, null);
@@ -121,10 +121,10 @@ public final class MetaContext {
 
     /**
      * Access the given context property.
-     * @param key the key, not the default value.
-     * @param defaultValue the default value to be returned, if no value is defined, or the
-     *                     stored value's TTL has been reached.
-     * @return the value, default value or null.
+     * @param key the key, not the default createValue.
+     * @param defaultValue the default createValue to be returned, if no createValue is defined, or the
+     *                     stored createValue's TTL has been reached.
+     * @return the createValue, default createValue or null.
      */
     public String getProperty(String key, String defaultValue){
         Value value = this.properties.get(key);
@@ -141,8 +141,8 @@ public final class MetaContext {
     /**
      * Sets the given context property.
      * @param key the key, not null.
-     * @param value the value, not null.
-     * @return the previous value, or null.
+     * @param value the createValue, not null.
+     * @return the previous createValue, or null.
      */
     public String setProperty(String key, String value){
        return setProperty(key, value, 0, TimeUnit.MILLISECONDS);
@@ -151,10 +151,10 @@ public final class MetaContext {
     /**
      * Sets the given context property.
      * @param key the key, not null.
-     * @param value the value, not null.
+     * @param value the createValue, not null.
      * @param ttl the time to live. Zero or less than zero means, no timeout.
      * @param unit the target time unit.
-     * @return the previous value, or null.
+     * @return the previous createValue, or null.
      */
     public String setProperty(String key, String value, int ttl, TimeUnit unit){
         Value previous = this.properties.put(key, new Value(key, value, ttl));
@@ -165,18 +165,18 @@ public final class MetaContext {
     }
 
     /**
-     * Sets the given property unless there is already a value defined.
+     * Sets the given property unless there is already a createValue defined.
      * @param key the key, not null.
-     * @param value the value, not null.
+     * @param value the createValue, not null.
      */
     public void setPropertyIfAbsent(String key, String value){
         setPropertyIfAbsent(key, value, 0, TimeUnit.MILLISECONDS);
     }
 
     /**
-     * Sets the given property unless there is already a value defined.
+     * Sets the given property unless there is already a createValue defined.
      * @param key the key, not null.
-     * @param value the value, not null.
+     * @param value the createValue, not null.
      * @param ttl the time to live. Zero or less than zero means, no timeout.
      * @param unit the target time unit.
      */
@@ -277,12 +277,12 @@ public final class MetaContext {
             }
         }
 
-        /** Method to check if a value is still valid. */
+        /** Method to check if a createValue is still valid. */
         boolean isValid(){
             return this.validUntil<=0 || this.validUntil>=System.currentTimeMillis();
         }
 
-        /** Method that invalidates a value. */
+        /** Method that invalidates a createValue. */
         void invalidate(){
             this.validUntil = 0;
         }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/SecuredFilter.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/SecuredFilter.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/SecuredFilter.java
index be9aaf9..bfa3672 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/SecuredFilter.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/SecuredFilter.java
@@ -29,7 +29,7 @@ import java.util.Map;
 import java.util.logging.Logger;
 
 /**
- * Simple filter that never changes a key/value pair returned, regardless if a value
+ * Simple filter that never changes a key/createValue pair returned, regardless if a createValue
  * is changing underneath, hereby different values for single and multi-property access
  * are considered.
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/EnabledPropertySourceProvider.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/EnabledPropertySourceProvider.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/EnabledPropertySourceProvider.java
index 6ccb734..ca7c46c 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/EnabledPropertySourceProvider.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/EnabledPropertySourceProvider.java
@@ -80,7 +80,7 @@ public final class EnabledPropertySourceProvider
 
     /**
      * Returns the enabled property.
-     * @return the enabled value.
+     * @return the enabled createValue.
      */
     @Override
     public boolean isEnabled(){
@@ -89,7 +89,7 @@ public final class EnabledPropertySourceProvider
 
     /**
      * Enables/disables this property source.
-     * @param enabled the enabled value.
+     * @param enabled the enabled createValue.
      */
     @Override
     public void setEnabled(boolean enabled){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/FilteredPropertySource.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/FilteredPropertySource.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/FilteredPropertySource.java
index 286507d..1fe93ff 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/FilteredPropertySource.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/ext/FilteredPropertySource.java
@@ -37,7 +37,7 @@ import org.apache.tamaya.spisupport.propertysource.BasePropertySource;
 
 /**
  * Property source that allows filtering on property source level. This class is thread-safe, accesses using or
- * changing the filter list are synchronized.
+ * changing the filter createList are synchronized.
  */
 public final class FilteredPropertySource extends BasePropertySource {
 
@@ -172,7 +172,7 @@ public final class FilteredPropertySource extends BasePropertySource {
 
     /**
      * Access the current filters present.
-     * @return a copy of the current filter list.
+     * @return a copy of the current filter createList.
      */
     public List<PropertyFilter> getPropertyFilter(){
         synchronized (filters){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentConfigurator.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentFactory.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentFactory.java
index e51fbde..2c36665 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentFactory.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentFactory.java
@@ -75,7 +75,7 @@ public final class ComponentFactory<T> {
                 }
             }
         }
-        // Multiple instances: create a new instance using the parameterless constructor for all subsequent
+        // Multiple instances: createObject a new instance using the parameterless constructor for all subsequent
         // resolutions.
         if(loaded.contains(comp.getClass().getName())){
             return (T)comp.getClass().newInstance();

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/PropertySourceReader.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/PropertySourceReader.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/PropertySourceReader.java
index 776dc46..0c42f8c 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/PropertySourceReader.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/PropertySourceReader.java
@@ -109,8 +109,8 @@ public class PropertySourceReader implements MetaConfigurationReader{
     /**
      * Decorates a property source to be refreshable or filtered.
      * @param ps the wrapped property source
-     *@param configNode the XML config getChild
-     * @param params the extracted parameter list   @return the property source to be added to the context.
+     *@param configNode the XML config getField
+     * @param params the extracted parameter createList   @return the property source to be added to the context.
      */
     private PropertySource decoratePropertySource(PropertySource ps, Node configNode, Map<String, String> params){
         Node refreshableVal = configNode.getAttributes().getNamedItem("refreshable");
@@ -161,8 +161,8 @@ public class PropertySourceReader implements MetaConfigurationReader{
     /**
      * Decorates a property source provider to be refreshable or filtered.
      * @param prov the property source provider to be wrapped.
-     * @param configNode the XML config getChild
-     * @param params the extracted parameter list   @return the property source provider to be added to the context.
+     * @param configNode the XML config getField
+     * @param params the extracted parameter createList   @return the property source provider to be added to the context.
      */
     private PropertySourceProvider decoratePropertySourceProvider(PropertySourceProvider prov, Node configNode, Map<String, String> params){
         Node refreshableVal = configNode.getAttributes().getNamedItem("refreshable");

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/ResourcePropertySourceProviderFactory.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/ResourcePropertySourceProviderFactory.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/ResourcePropertySourceProviderFactory.java
index 7b34ea4..8072a15 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/ResourcePropertySourceProviderFactory.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/ResourcePropertySourceProviderFactory.java
@@ -61,10 +61,10 @@ public class ResourcePropertySourceProviderFactory implements ItemFactory<Proper
                 ConfigurationData data;
                 try {
                     if (formats.length == 0) {
-                        data = ConfigurationFormats.readConfigurationData(resource);
+                        data = ConfigurationFormats.getInstance().readConfigurationData(resource);
                     } else {
-                        data = ConfigurationFormats.readConfigurationData(resource,
-                                ConfigurationFormats.getFormats(formats));
+                        data = ConfigurationFormats.getInstance().readConfigurationData(resource,
+                                ConfigurationFormats.getInstance().getFormats(formats));
                     }
                     propertySources.add(new MappedConfigurationDataPropertySource(data));
                 } catch (Exception e) {

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/URLPropertySourceFactory.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/URLPropertySourceFactory.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/URLPropertySourceFactory.java
index 227b6ef..0aa1c79 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/URLPropertySourceFactory.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/factories/URLPropertySourceFactory.java
@@ -114,10 +114,10 @@ public class URLPropertySourceFactory implements ItemFactory<PropertySource>{
             ConfigurationData data;
             try {
                 if (formats.length == 0) {
-                    data = ConfigurationFormats.readConfigurationData(resource);
+                    data = ConfigurationFormats.getInstance().readConfigurationData(resource);
                 } else {
-                    data = ConfigurationFormats.readConfigurationData(resource,
-                            ConfigurationFormats.getFormats(formats));
+                    data = ConfigurationFormats.getInstance().readConfigurationData(resource,
+                            ConfigurationFormats.getInstance().getFormats(formats));
                 }
                 return data;
             } catch (Exception e) {

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/resolver/PropertiesResolver.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/resolver/PropertiesResolver.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/resolver/PropertiesResolver.java
index 083daae..dcba85a 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/resolver/PropertiesResolver.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/resolver/PropertiesResolver.java
@@ -35,7 +35,7 @@ import java.net.URI;
  *     <li>{@code ${properties:ctx:[ctxName:]key?default=abcval} } reading a <i>default</i> MetaContext entry.</li>
  * </ul>
  *
- * Hereby the _default_ parameter defines the default value to be applied, if no value was found.
+ * Hereby the _default_ parameter defines the default createValue to be applied, if no createValue was found.
  */
 @Component
 public final class PropertiesResolver implements SimpleResolver{

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/spi/ItemFactoryManager.java
----------------------------------------------------------------------
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/spi/ItemFactoryManager.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/spi/ItemFactoryManager.java
index 7dcb4c7..2183b1a 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/spi/ItemFactoryManager.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/spi/ItemFactoryManager.java
@@ -79,7 +79,7 @@ public final class ItemFactoryManager {
             registerItemFactory(factory);
             return factory;
         }catch(Exception e){
-            LOG.severe("Failed to create factory for configured class: " + type.getName() +
+            LOG.severe("Failed to createObject factory for configured class: " + type.getName() +
                     " and type: " + id);
             return null;
         }
@@ -114,7 +114,7 @@ public final class ItemFactoryManager {
             try {
                 return instanceType.newInstance();
             } catch (Exception e) {
-                LOG.log(Level.SEVERE, "Failed to create configured instance of type:" + instanceType, e);
+                LOG.log(Level.SEVERE, "Failed to createObject configured instance of type:" + instanceType, e);
                 return null;
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/test/java/org/apache/tamaya/metamodel/internal/resolver/JavaResolverTest.java
----------------------------------------------------------------------
diff --git a/metamodel/src/test/java/org/apache/tamaya/metamodel/internal/resolver/JavaResolverTest.java b/metamodel/src/test/java/org/apache/tamaya/metamodel/internal/resolver/JavaResolverTest.java
index 0c1bfb3..93ccd56 100644
--- a/metamodel/src/test/java/org/apache/tamaya/metamodel/internal/resolver/JavaResolverTest.java
+++ b/metamodel/src/test/java/org/apache/tamaya/metamodel/internal/resolver/JavaResolverTest.java
@@ -40,7 +40,7 @@ public class JavaResolverTest {
 
     @Test
     public void evaluateDirect() throws Exception {
-        assertEquals("value", r.evaluate("\"value\""));
+        assertEquals("createValue", r.evaluate("\"createValue\""));
         assertEquals("1.1", r.evaluate("1.1"));
         assertEquals("1", r.evaluate("1"));
     }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/propertysources/src/main/java/org/apache/tamaya/propertysources/ConfigDirPropertySourceProvider.java
----------------------------------------------------------------------
diff --git a/propertysources/src/main/java/org/apache/tamaya/propertysources/ConfigDirPropertySourceProvider.java b/propertysources/src/main/java/org/apache/tamaya/propertysources/ConfigDirPropertySourceProvider.java
index faf2b21..c8b70e2 100644
--- a/propertysources/src/main/java/org/apache/tamaya/propertysources/ConfigDirPropertySourceProvider.java
+++ b/propertysources/src/main/java/org/apache/tamaya/propertysources/ConfigDirPropertySourceProvider.java
@@ -60,7 +60,7 @@ public class ConfigDirPropertySourceProvider extends AbstractPathPropertySourceP
     @Override
     protected Collection<PropertySource> getPropertySources(URL url) {
         try {
-            ConfigurationData config = ConfigurationFormats.readConfigurationData(url);
+            ConfigurationData config = ConfigurationFormats.getInstance(getClassLoader()).readConfigurationData(url);
             if (config == null) {
                 Logger.getLogger(getClass().getName()).log(Level.INFO,
                         "Failed to read configuration from " + url);

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/propertysources/src/main/java/org/apache/tamaya/propertysources/MetainfConfigPropertySourceProvider.java
----------------------------------------------------------------------
diff --git a/propertysources/src/main/java/org/apache/tamaya/propertysources/MetainfConfigPropertySourceProvider.java b/propertysources/src/main/java/org/apache/tamaya/propertysources/MetainfConfigPropertySourceProvider.java
index d450842..4c4f5a6 100644
--- a/propertysources/src/main/java/org/apache/tamaya/propertysources/MetainfConfigPropertySourceProvider.java
+++ b/propertysources/src/main/java/org/apache/tamaya/propertysources/MetainfConfigPropertySourceProvider.java
@@ -46,7 +46,7 @@ public class MetainfConfigPropertySourceProvider extends AbstractPathPropertySou
     @Override
     protected Collection<PropertySource> getPropertySources(URL url) {
         try {
-            ConfigurationData config = ConfigurationFormats.readConfigurationData(url);
+            ConfigurationData config = ConfigurationFormats.getInstance(getClassLoader()).readConfigurationData(url);
             return Collections.singleton(new MappedConfigurationDataPropertySource(config));
         } catch (Exception e) {
             Logger.getLogger(getClass().getName()).log(Level.SEVERE,

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/propertysources/src/main/java/org/apache/tamaya/propertysources/SimplePropertySourceBuilder.java
----------------------------------------------------------------------
diff --git a/propertysources/src/main/java/org/apache/tamaya/propertysources/SimplePropertySourceBuilder.java b/propertysources/src/main/java/org/apache/tamaya/propertysources/SimplePropertySourceBuilder.java
index 884ca61..8204c0c 100644
--- a/propertysources/src/main/java/org/apache/tamaya/propertysources/SimplePropertySourceBuilder.java
+++ b/propertysources/src/main/java/org/apache/tamaya/propertysources/SimplePropertySourceBuilder.java
@@ -61,9 +61,9 @@ public final class SimplePropertySourceBuilder {
     }
 
     /**
-     * Sets a new property key/value.
+     * Sets a new property key/createValue.
      * @param key the property key, not null.
-     * @param value the property value, not null.
+     * @param value the property createValue, not null.
      * @return the bulder for chaining.
      */
     public SimplePropertySourceBuilder put(String key, String value){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/remote/src/main/java/org/apache/tamaya/remote/BaseRemotePropertySource.java
----------------------------------------------------------------------
diff --git a/remote/src/main/java/org/apache/tamaya/remote/BaseRemotePropertySource.java b/remote/src/main/java/org/apache/tamaya/remote/BaseRemotePropertySource.java
index f1b600a..3c6b106 100644
--- a/remote/src/main/java/org/apache/tamaya/remote/BaseRemotePropertySource.java
+++ b/remote/src/main/java/org/apache/tamaya/remote/BaseRemotePropertySource.java
@@ -93,7 +93,7 @@ public abstract class BaseRemotePropertySource implements PropertySource{
         Map<String,String> readProperties = new HashMap<>();
         if(data!=null){
             for(PropertyValue val:data.getData()) {
-                readProperties.putAll(val.asMap());
+                readProperties.putAll(val.toMap());
             }
             Map<String,String> newProperties = new HashMap<>();
             for(Map.Entry<String,String> en:readProperties.entrySet()){
@@ -138,7 +138,7 @@ public abstract class BaseRemotePropertySource implements PropertySource{
     }
 
     /**
-     * Returns the  default ordinal used, when no ordinal is setCurrent, or the ordinal was not parseable to an int value.
+     * Returns the  default ordinal used, when no ordinal is setCurrent, or the ordinal was not parseable to an int createValue.
      * @return the  default ordinal used, by default 0.
      */
     public int getDefaultOrdinal(){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/uom/src/test/java/org/apache/tamaya/uom/UnitConverterTest.java
----------------------------------------------------------------------
diff --git a/uom/src/test/java/org/apache/tamaya/uom/UnitConverterTest.java b/uom/src/test/java/org/apache/tamaya/uom/UnitConverterTest.java
index c809272..0afe8c9 100644
--- a/uom/src/test/java/org/apache/tamaya/uom/UnitConverterTest.java
+++ b/uom/src/test/java/org/apache/tamaya/uom/UnitConverterTest.java
@@ -36,7 +36,7 @@ public class UnitConverterTest {
 
 		Unit<?> unit = converter.convert("m");
 
-		assertThat("Converter failed to convert input value " + unit, notNullValue());
+		assertThat("Converter failed to convert input createValue " + unit, notNullValue());
 		assertEquals(unit, Units.METRE);
 	}
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/main/java/org/apache/tamaya/usagetracker/ConfigUsage.java
----------------------------------------------------------------------
diff --git a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/ConfigUsage.java b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/ConfigUsage.java
index ccb27cf..1bfacb4 100644
--- a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/ConfigUsage.java
+++ b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/ConfigUsage.java
@@ -61,7 +61,7 @@ public final class ConfigUsage {
     }
 
     /**
-     * Adds the given packageNames to the list of packages to be ignored when collecting usage data.
+     * Adds the given packageNames to the createList of packages to be ignored when collecting usage data.
      * @param packageName the package names to be added, not null.
      */
     public static void addIgnoredPackages(String... packageName){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/main/java/org/apache/tamaya/usagetracker/UsageStat.java
----------------------------------------------------------------------
diff --git a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/UsageStat.java b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/UsageStat.java
index 4239050..bab6312 100644
--- a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/UsageStat.java
+++ b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/UsageStat.java
@@ -70,7 +70,7 @@ public final class UsageStat {
 
     /**
      * Sets the maximal length of the stacktraces stored when tracking configuration
-     * usage. Setting it to a negative value, disabled stacktrace logging.
+     * usage. Setting it to a negative createValue, disabled stacktrace logging.
      * @param maxTrace the maximal recorded stack length.
      */
     public static void setMaxTrace(int maxTrace){
@@ -117,7 +117,7 @@ public final class UsageStat {
 
     /**
      * Access access details for a given class.
-     * @param type class to getChild usage access stats for, not null.
+     * @param type class to getField usage access stats for, not null.
      * @return the usage ref, if present, or null.
      */
     public Collection<AccessStats> getAccessDetails(Class type){
@@ -126,7 +126,7 @@ public final class UsageStat {
 
     /**
      * Access access details for a given package.
-     * @param pack package to getChild usage access stats for, not null.
+     * @param pack package to getField usage access stats for, not null.
      * @return the usage ref, if present, or null.
      */
     public Collection<AccessStats> getAccessDetails(Package pack){
@@ -167,9 +167,9 @@ public final class UsageStat {
 
     /**
      * Evaluates the current access point from the current stacktrace and adds an according
-     * usage reference object (or updates any existing one) for the given key. The
+     * usage reference createObject (or updates any existing one) for the given key. The
      * stacktrace is shortened to a maximal getNumChilds of 20 items.
-     * @param value the value returned, not null.
+     * @param value the createValue returned, not null.
      */
     public void trackUsage(PropertyValue value){
         trackUsage(value, maxTrace);
@@ -177,8 +177,8 @@ public final class UsageStat {
 
     /**
      * Evaluates the current access point from the current stacktrace and adds an according
-     * usage reference object (or updates any existing one) for the given key.
-     * @param value the value returned, not null.
+     * usage reference createObject (or updates any existing one) for the given key.
+     * @param value the createValue returned, not null.
      * @param maxTraceLength the maximal length of the stored stacktrace.
      */
     public void trackUsage(PropertyValue value, int maxTraceLength){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/DefaultConfigUsage.java
----------------------------------------------------------------------
diff --git a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/DefaultConfigUsage.java b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/DefaultConfigUsage.java
index 759082a..ea0a6e6 100644
--- a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/DefaultConfigUsage.java
+++ b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/DefaultConfigUsage.java
@@ -113,7 +113,7 @@ public class DefaultConfigUsage implements ConfigUsageSpi {
 
     @Override
     public void recordAllPropertiesAccess(ConfigurationContext context){
-        recordSingleKeyAccess(PropertyValue.create("<<all>>","<not stored>"), context);
+        recordSingleKeyAccess(PropertyValue.createValue("<<all>>","<not stored>"), context);
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/UsageTrackerFilter.java
----------------------------------------------------------------------
diff --git a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/UsageTrackerFilter.java b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/UsageTrackerFilter.java
index 11644c7..0c67354 100644
--- a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/UsageTrackerFilter.java
+++ b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/internal/UsageTrackerFilter.java
@@ -29,7 +29,7 @@ import java.util.logging.Filter;
 
 /**
  * Configuration filter to be applied at the end of the filter chain. This filter
- * actually does not change the current filter value, but use the filter process
+ * actually does not change the current filter createValue, but use the filter process
  * to track configuration usage.
  */
 @Priority(Integer.MAX_VALUE)

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/main/java/org/apache/tamaya/usagetracker/spi/ConfigUsageSpi.java
----------------------------------------------------------------------
diff --git a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/spi/ConfigUsageSpi.java b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/spi/ConfigUsageSpi.java
index e3d3d7e..cdaad4f 100644
--- a/usagetracker/src/main/java/org/apache/tamaya/usagetracker/spi/ConfigUsageSpi.java
+++ b/usagetracker/src/main/java/org/apache/tamaya/usagetracker/spi/ConfigUsageSpi.java
@@ -44,13 +44,13 @@ public interface ConfigUsageSpi {
     boolean isTrackingEnabled();
 
     /**
-     * Get the list of packages, which are not evaluated for tracking configuration access and usage statistics.
+     * Get the createList of packages, which are not evaluated for tracking configuration access and usage statistics.
      * @return the setCurrent of ignored package names.
      */
     Set<String> getIgnoredPackages();
 
     /**
-     * Adds the given packageNames to the list of packages to be ignored when collecting usage data.
+     * Adds the given packageNames to the createList of packages to be ignored when collecting usage data.
      * @param packageName the package names to be added, not null.
      */
     void addIgnoredPackages(String... packageName);
@@ -84,10 +84,10 @@ public interface ConfigUsageSpi {
     void recordAllPropertiesAccess(ConfigurationContext context);
 
     /**
-     * Track the access of {@code Configuration#getChild(String)} for
+     * Track the access of {@code Configuration#getField(String)} for
      * usage statistics.
      * @param context the corresponding context.
-     * @param value value to track for
+     * @param value createValue to track for
      */
     void recordSingleKeyAccess(PropertyValue value, ConfigurationContext context);
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/test/resources/examples/configmodel.json
----------------------------------------------------------------------
diff --git a/usagetracker/src/test/resources/examples/configmodel.json b/usagetracker/src/test/resources/examples/configmodel.json
index 529f26e..1e3d676 100644
--- a/usagetracker/src/test/resources/examples/configmodel.json
+++ b/usagetracker/src/test/resources/examples/configmodel.json
@@ -21,7 +21,7 @@
 // Example of a configuration metamodel expressed via YAML(tm).
 //  Structure is shown through indentation (one or more spaces).
 //  Sequence items are denoted by a dash,
-//  key value pairs within a map are separated by a colon.
+//  key createValue pairs within a map are separated by a colon.
 //##################################################################################
 
 //##################################################################################

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/test/resources/examples/configmodel.xml
----------------------------------------------------------------------
diff --git a/usagetracker/src/test/resources/examples/configmodel.xml b/usagetracker/src/test/resources/examples/configmodel.xml
index f23f783..eb58169 100644
--- a/usagetracker/src/test/resources/examples/configmodel.xml
+++ b/usagetracker/src/test/resources/examples/configmodel.xml
@@ -21,7 +21,7 @@ under the License.
 # Example of a configuration metamodel expressed via YAML(tm).
 #   Structure is shown through indentation (one or more spaces).
 #   Sequence items are denoted by a dash,
-#   key value pairs within a map are separated by a colon.
+#   key createValue pairs within a map are separated by a colon.
 #################################################################################-->
 
 <!--################################################################################

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/usagetracker/src/test/resources/examples/configmodel.yaml
----------------------------------------------------------------------
diff --git a/usagetracker/src/test/resources/examples/configmodel.yaml b/usagetracker/src/test/resources/examples/configmodel.yaml
index 041c801..041fb56 100644
--- a/usagetracker/src/test/resources/examples/configmodel.yaml
+++ b/usagetracker/src/test/resources/examples/configmodel.yaml
@@ -21,7 +21,7 @@
 # Example of a configuration metamodel expressed via YAML(tm).
 #   Structure is shown through indentation (one or more spaces).
 #   Sequence items are denoted by a dash,
-#   key value pairs within a map are separated by a colon.
+#   key createValue pairs within a map are separated by a colon.
 ####################################################################################
 
 ####################################################################################

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/pom.xml
----------------------------------------------------------------------
diff --git a/validation/pom.xml b/validation/pom.xml
index 7252316..c3ef7cf 100644
--- a/validation/pom.xml
+++ b/validation/pom.xml
@@ -5,7 +5,7 @@
   ~  regarding copyright ownership.  The ASF licenses this file
   ~  to you under the Apache License, Version 2.0 (the
   ~  "License"); you may not use this file except in compliance
-  ~  with the License.  You may obtain a copy create the License at
+  ~  with the License.  You may obtain a copy createObject the License at
   ~
   ~     http://www.apache.org/licenses/LICENSE-2.0
   ~

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/ConfigModel.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/ConfigModel.java b/validation/src/main/java/org/apache/tamaya/validation/ConfigModel.java
index b6da54b..259ff99 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/ConfigModel.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/ConfigModel.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -29,12 +29,12 @@ public interface ConfigModel {
 
     /**
      * Access the owner.
-     * @return the owner create this model, never null.
+     * @return the owner createObject this model, never null.
      */
     String getOwner();
 
     /**
-     * Get the type create item that is modelled.
+     * Get the type createObject item that is modelled.
      * @return the modelled type, never null.
      */
     ModelTarget getType();
@@ -59,7 +59,7 @@ public interface ConfigModel {
     boolean isRequired();
 
     /**
-     * Get an description create the item, using the default locale. The description is basically optional
+     * Get an description createObject the item, using the default locale. The description is basically optional
      * though it is higly recommended to provide a description, so the validation issues is well
      * resolvable.
      *
@@ -68,7 +68,7 @@ public interface ConfigModel {
     String getDescription();
 
     /**
-     * Validates the item and all its getChildren against the given configuration.
+     * Validates the item and all its getList against the given configuration.
      *
      * @param config the configuration to be validated against, not null.
      * @return the validation result, or null, if not applicable.

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/ConfigModelManager.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/ConfigModelManager.java b/validation/src/main/java/org/apache/tamaya/validation/ConfigModelManager.java
index b4a89ad..ed6a545 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/ConfigModelManager.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/ConfigModelManager.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -54,7 +54,7 @@ public final class ConfigModelManager {
     }
 
     /**
-     * Access the usage statistics for the recorded uses create configuration.
+     * Access the usage statistics for the recorded uses createObject configuration.
      * @param inModels the target models, not null.
      * @return usage statistics
      */
@@ -204,7 +204,7 @@ public final class ConfigModelManager {
                 for (ConfigModel defConf : getModels()) {
                     if(ModelTarget.Section.equals(defConf.getType())){
                         if(defConf.getName().endsWith(".*") && entry.getKey().matches(defConf.getName())){
-                            // Ignore parameters that are part create transitive section.
+                            // Ignore parameters that are part createObject transitive section.
                             continue outer;
                         }
                     }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/ModelTarget.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/ModelTarget.java b/validation/src/main/java/org/apache/tamaya/validation/ModelTarget.java
index db10306..3af63ae 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/ModelTarget.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/ModelTarget.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -19,7 +19,7 @@
 package org.apache.tamaya.validation;
 
 /**
- * This enumeration defines the types create supported validations.
+ * This enumeration defines the types createObject supported validations.
  */
 public enum ModelTarget {
     /**
@@ -31,7 +31,7 @@ public enum ModelTarget {
      */
     Parameter,
     /**
-     * ConfigModel that is a container create other validations.
+     * ConfigModel that is a container createObject other validations.
      */
     Group,
 }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/Validation.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/Validation.java b/validation/src/main/java/org/apache/tamaya/validation/Validation.java
index 7d17da3..128efee 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/Validation.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/Validation.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -46,7 +46,7 @@ public final class Validation {
      * Creates a new ValidationResult.
      *
      * @param configModel the configModel item, not null.
-     * @return a new validation result containing valid parts create the given model.
+     * @return a new validation result containing valid parts createObject the given model.
      */
     public static Validation createValid(ConfigModel configModel) {
         return new Validation(configModel, ValidationResult.VALID, null);
@@ -56,7 +56,7 @@ public final class Validation {
      * Creates a new ValidationResult.
      *
      * @param configModel the configModel item, not null.
-     * @return a new validation result containing missing parts create the given model.
+     * @return a new validation result containing missing parts createObject the given model.
      */
     public static Validation createMissing(ConfigModel configModel) {
         return new Validation(configModel, ValidationResult.MISSING, null);
@@ -67,7 +67,7 @@ public final class Validation {
      *
      * @param configModel the configModel item, not null.
      * @param message Additional message to be shown (optional).
-     * @return a new validation result containing missing parts create the given model with a message.
+     * @return a new validation result containing missing parts createObject the given model with a message.
      */
     public static Validation createMissing(ConfigModel configModel, String message) {
         return new Validation(configModel, ValidationResult.MISSING, message);
@@ -78,7 +78,7 @@ public final class Validation {
      *
      * @param configModel the configModel item, not null.
      * @param error error message to addNode.
-     * @return a new validation result containing erroneous parts create the given model with the given error message.
+     * @return a new validation result containing erroneous parts createObject the given model with the given error message.
      */
     public static Validation createError(ConfigModel configModel, String error) {
         return new Validation(configModel, ValidationResult.ERROR, error);
@@ -89,7 +89,7 @@ public final class Validation {
      *
      * @param configModel the configModel item, not null.
      * @param warning warning message to addNode.
-     * @return a new validation result containing warning parts create the given model with the given warning message.
+     * @return a new validation result containing warning parts createObject the given model with the given warning message.
      */
     public static Validation createWarning(ConfigModel configModel, String warning) {
         return new Validation(configModel, ValidationResult.WARNING, warning);
@@ -100,7 +100,7 @@ public final class Validation {
      *
      * @param configModel the configModel item, not null.
      * @param alternativeUsage allows setting a message to indicate non-deprecated replacement, maybe null.
-     * @return a new validation result containing deprecated parts create the given model with an optional message.
+     * @return a new validation result containing deprecated parts createObject the given model with an optional message.
      */
     public static Validation createDeprecated(ConfigModel configModel, String alternativeUsage) {
         return new Validation(configModel, ValidationResult.DEPRECATED, alternativeUsage != null ? "Use instead: " + alternativeUsage : null);
@@ -110,7 +110,7 @@ public final class Validation {
      * Creates a new ValidationResult.
      *
      * @param configModel the configModel item, not null.
-     * @return a new validation result containing deprecated parts create the given model.
+     * @return a new validation result containing deprecated parts createObject the given model.
      */
     public static Validation createDeprecated(ConfigModel configModel) {
         return new Validation(configModel, ValidationResult.DEPRECATED, null);

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/ValidationResult.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/ValidationResult.java b/validation/src/main/java/org/apache/tamaya/validation/ValidationResult.java
index f0afc68..942a755 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/ValidationResult.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/ValidationResult.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -31,7 +31,7 @@ public enum ValidationResult {
      */
     DEPRECATED,
     /**
-     * The validated item is correct, but the value is worth a warning.
+     * The validated item is correct, but the createValue is worth a warning.
      */
     WARNING,
     /**
@@ -44,7 +44,7 @@ public enum ValidationResult {
      */
     MISSING,
     /**
-     * The validated item has an invalid value.
+     * The validated item has an invalid createValue.
      */
     ERROR;
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/internal/ConfigDocumentationBean.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfigDocumentationBean.java b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfigDocumentationBean.java
index 754bfa2..14d4d02 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfigDocumentationBean.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfigDocumentationBean.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -42,7 +42,7 @@ import java.util.List;
 import java.util.Map;
 
 /**
- * MBean implementation create {@link ConfigDocumentationMBean}.
+ * MBean implementation createObject {@link ConfigDocumentationMBean}.
  */
 public class ConfigDocumentationBean implements ConfigDocumentationMBean{
 

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredInlineModelProviderSpi.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredInlineModelProviderSpi.java b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredInlineModelProviderSpi.java
index a42fbf6..685271e 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredInlineModelProviderSpi.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredInlineModelProviderSpi.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredPropertiesModelProviderSpi.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredPropertiesModelProviderSpi.java b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredPropertiesModelProviderSpi.java
index cd8e1e5..623e0e9 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredPropertiesModelProviderSpi.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredPropertiesModelProviderSpi.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -35,14 +35,14 @@ import java.util.logging.Logger;
  * {@code classpath*:META-INF/configmodel.properties} in the following format:
  * <pre>
  * ###################################################################################
- * # Example create a configuration metamodel expressed via properties.
+ * # Example createObject a configuration metamodel expressed via properties.
  * ####################################################################################
  *
  * # Metamodel information
  * [model].provider=ConfigModel Extension
  *
  * ####################################################################################
- * # Description create Configuration Sections (minimal, can be extended by other modules).
+ * # Description createObject Configuration Sections (minimal, can be extended by other modules).
  * # By default its interpreted as a section !
  * ####################################################################################
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredResourcesModelProviderSpi.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredResourcesModelProviderSpi.java b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredResourcesModelProviderSpi.java
index 03d0fb6..679ccf3 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredResourcesModelProviderSpi.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredResourcesModelProviderSpi.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -28,21 +28,21 @@ import java.util.logging.Logger;
 import org.apache.tamaya.Configuration;
 import org.apache.tamaya.format.ConfigurationData;
 import org.apache.tamaya.format.ConfigurationFormats;
+import org.apache.tamaya.resource.ResourceResolver;
 import org.apache.tamaya.spi.ClassloaderAware;
 import org.apache.tamaya.spi.PropertyValue;
 import org.apache.tamaya.validation.ConfigModel;
 import org.apache.tamaya.validation.spi.ConfigModelReader;
 import org.apache.tamaya.validation.spi.ModelProviderSpi;
-import org.apache.tamaya.resource.ConfigResources;
 
 /**
  * ConfigModel provider that reads model metadata from property files from
  * {@code classpath*:META-INF/configmodel.json} in the following format:
  * <pre>
- *  Example create a configuration metamodel expressed via YAML.
+ *  Example createObject a configuration metamodel expressed via YAML.
  *  Structure is shown through indentation (one or more spaces).
  *  Sequence items are denoted by a dash,
- *  key value pairs within a map are separated by a colon.
+ *  key createValue pairs within a map are separated by a colon.
  * </pre>
  */
 public class ConfiguredResourcesModelProviderSpi implements ModelProviderSpi, ClassloaderAware {
@@ -52,15 +52,15 @@ public class ConfiguredResourcesModelProviderSpi implements ModelProviderSpi, Cl
      */
     private static final Logger LOG = Logger.getLogger(ConfiguredResourcesModelProviderSpi.class.getName());
     /**
-     * The parameter that can be used to configure the location create the configuration model resources.
+     * The parameter that can be used to configure the location createObject the configuration model resources.
      */
     private static final String MODEL_RESOURCE_PARAM = "org.apache.tamaya.model.resources";
     /**
-     * The resource class to checked for testing the availability create the resources extension module.
+     * The resource class to checked for testing the availability createObject the resources extension module.
      */
     private static final String CONFIG_RESOURCE_CLASS = "org.apache.tamaya.resource.ConfigResource";
     /**
-     * The resource class to checked for testing the availability create the formats extension module.
+     * The resource class to checked for testing the availability createObject the formats extension module.
      */
     private static final String CONFIGURATION_FORMATS_CLASS = "org.apache.tamaya.format.ConfigurationFormats";
     /**
@@ -128,7 +128,7 @@ public class ConfiguredResourcesModelProviderSpi implements ModelProviderSpi, Cl
         Collection<URL> urls;
         if (RESOURCES_EXTENSION_AVAILABLE) {
             LOG.info("Using tamaya-resources extension to read model configuration from " + resources);
-            urls = ConfigResources.getResourceResolver(classLoader).getResources(resources.split(","));
+            urls = ResourceResolver.current(classLoader).getResources(resources.split(","));
         } else {
             LOG.info("Using default classloader resource location to read model configuration from " + resources);
             urls = new ArrayList<>();
@@ -150,10 +150,11 @@ public class ConfiguredResourcesModelProviderSpi implements ModelProviderSpi, Cl
         // Reading configs
         for (final URL config : urls) {
             try (InputStream is = config.openStream()) {
-                final ConfigurationData data = ConfigurationFormats.readConfigurationData(config);
+                final ConfigurationData data = ConfigurationFormats.getInstance()
+                   .readConfigurationData(config);
                 Map<String,String> props = new HashMap<>();
                 for(PropertyValue val:data.getData()){
-                    props.putAll(val.asMap());
+                    props.putAll(val.toMap());
                 }
                 String owner = props.get("_model.provider");
                 if(owner==null){

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelPopulator.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelPopulator.java b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelPopulator.java
index 16c484f..7436a81 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelPopulator.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelPopulator.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -35,7 +35,7 @@ import java.util.Objects;
 import java.util.logging.Logger;
 
 /**
- * Internal facade that registers all kind create injected fields as {@link org.apache.tamaya.validation.ConfigModel} entries,
+ * Internal facade that registers all kind createObject injected fields as {@link org.apache.tamaya.validation.ConfigModel} entries,
  * so all configured injection points are visible as documented configuration hooks.
  */
 public final class ConfiguredTypeEventsModelPopulator implements ConfigEventListener, ClassloaderAware {
@@ -45,7 +45,7 @@ public final class ConfiguredTypeEventsModelPopulator implements ConfigEventList
      */
     private static final Logger LOG = Logger.getLogger(ConfiguredTypeEventsModelPopulator.class.getName());
 
-    /** System property to be setCurrent to deactivate auto documentation create configured classes published thorugh
+    /** System property to be setCurrent to deactivate auto documentation createObject configured classes published thorugh
      * ConfiguredType events.
      */
     private static final String ENABLE_EVENT_DOC = "org.apache.tamaya.model.autoModelEvents";
@@ -97,8 +97,8 @@ public final class ConfiguredTypeEventsModelPopulator implements ConfigEventList
      *
      * @param classLoader the target classloader, not null.
      * @param name the name to use, not null.
-     * @param modelType classname create the target model type.
-     * @param <T> type create the model to filter for.
+     * @param modelType classname createObject the target model type.
+     * @param <T> type createObject the model to filter for.
      * @return the sections defined, never null.
      */
     private static <T extends ConfigModel> T getModel(String name, Class<T> modelType, ClassLoader classLoader) {

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelProvider.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelProvider.java b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelProvider.java
index ae267a4..e1708eb 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelProvider.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/internal/ConfiguredTypeEventsModelProvider.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/spi/AbstractConfigModel.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/spi/AbstractConfigModel.java b/validation/src/main/java/org/apache/tamaya/validation/spi/AbstractConfigModel.java
index 5ba357c..37fbfe1 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/spi/AbstractConfigModel.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/spi/AbstractConfigModel.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigDocumentationMBean.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigDocumentationMBean.java b/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigDocumentationMBean.java
index fa62b19..21e5ea1 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigDocumentationMBean.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigDocumentationMBean.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigModelReader.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigModelReader.java b/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigModelReader.java
index 76fadb5..5b806af 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigModelReader.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/spi/ConfigModelReader.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -28,9 +28,9 @@ import java.util.Set;
 import org.apache.tamaya.validation.ConfigModel;
 
 /**
- * Utility class to read metamodel information from properties. Hereby these properties can be part create a
+ * Utility class to read metamodel information from properties. Hereby these properties can be part createObject a
  * configuration (containing other entriees as well) or be dedicated model definition properties read
- * from any kind create source.
+ * from any kind createObject source.
  */
 public final class ConfigModelReader {
 
@@ -47,7 +47,7 @@ public final class ConfigModelReader {
      * Loads validations as configured in the given properties.
      * @param owner owner, not null.
      * @param props the properties to be read
-     * @return a collection create config validations.
+     * @return a collection createObject config validations.
      */
     public static Collection<ConfigModel> loadValidations(String owner, Map<String,String> props) {
         List<ConfigModel> result = new ArrayList<>();
@@ -95,7 +95,7 @@ public final class ConfigModelReader {
      * @param paramName the param name, not null.
      * @param description the optional description
      * @param type the param type, default is String.
-     * @param reqVal the required value, default is 'false'.
+     * @param reqVal the required createValue, default is 'false'.
      * @param regEx an optional regular expression to be checked for this param
      * @param validations the optional custom validations to be performed.
      * @return the new validation for this parameter.
@@ -120,7 +120,7 @@ public final class ConfigModelReader {
      * Creates a section validation.
      * @param sectionName the section's name, not null.
      * @param description the optional description
-     * @param reqVal the required value, default is 'false'.
+     * @param reqVal the required createValue, default is 'false'.
      * @param validations the optional custom validations to be performed.
      * @return the new validation for this section.
      */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/spi/GroupModel.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/spi/GroupModel.java b/validation/src/main/java/org/apache/tamaya/validation/spi/GroupModel.java
index 4783f55..2957576 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/spi/GroupModel.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/spi/GroupModel.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/spi/ModelProviderSpi.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/spi/ModelProviderSpi.java b/validation/src/main/java/org/apache/tamaya/validation/spi/ModelProviderSpi.java
index e05e1d2..74bccd1 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/spi/ModelProviderSpi.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/spi/ModelProviderSpi.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -23,7 +23,7 @@ import org.apache.tamaya.validation.ConfigModel;
 import java.util.Collection;
 
 /**
- * Model create a configuration state. A model can be a full model, or a partial model, validating only
+ * Model createObject a configuration state. A model can be a full model, or a partial model, validating only
  * a configuration subset. This allows better user feedback because big configurations can be grouped
  * and validated by multiple (partial) models.
  */

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/spi/ParameterModel.java
----------------------------------------------------------------------
diff --git a/validation/src/main/java/org/apache/tamaya/validation/spi/SectionModel.java b/validation/src/main/java/org/apache/tamaya/validation/spi/SectionModel.java
index ca929ec..79ee50e 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/spi/SectionModel.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/spi/SectionModel.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/test/java/org/apache/tamaya/validation/ConfigModelProviderTest.java
----------------------------------------------------------------------
diff --git a/validation/src/test/java/org/apache/tamaya/validation/ConfigModelProviderTest.java b/validation/src/test/java/org/apache/tamaya/validation/ConfigModelProviderTest.java
index 20686c6..8edf50d 100644
--- a/validation/src/test/java/org/apache/tamaya/validation/ConfigModelProviderTest.java
+++ b/validation/src/test/java/org/apache/tamaya/validation/ConfigModelProviderTest.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/test/java/org/apache/tamaya/validation/ValidationTests.java
----------------------------------------------------------------------
diff --git a/validation/src/test/java/org/apache/tamaya/validation/ValidationTests.java b/validation/src/test/java/org/apache/tamaya/validation/ValidationTests.java
index 40fe9ec..bca328c 100644
--- a/validation/src/test/java/org/apache/tamaya/validation/ValidationTests.java
+++ b/validation/src/test/java/org/apache/tamaya/validation/ValidationTests.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/test/java/org/apache/tamaya/validation/internal/ConfigDocumentationBeanTest.java
----------------------------------------------------------------------
diff --git a/validation/src/test/java/org/apache/tamaya/validation/internal/ConfigDocumentationBeanTest.java b/validation/src/test/java/org/apache/tamaya/validation/internal/ConfigDocumentationBeanTest.java
index 25de13f..b6a1203 100644
--- a/validation/src/test/java/org/apache/tamaya/validation/internal/ConfigDocumentationBeanTest.java
+++ b/validation/src/test/java/org/apache/tamaya/validation/internal/ConfigDocumentationBeanTest.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -48,7 +48,7 @@ public class ConfigDocumentationBeanTest {
         String results = mbean.validate(true);
         assertNotNull(results);
         assertFalse(results.trim().isEmpty());
-        // test transitive excludes create default sys properties
+        // test transitive excludes createObject default sys properties
         assertFalse(results.contains("\"name\":\"java"));
         assertFalse(results.contains("\"name\":\"sun."));
         assertFalse(results.contains("\"name\":\"file."));

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/test/java/test/model/TestConfigAccessor.java
----------------------------------------------------------------------
diff --git a/validation/src/test/java/test/model/TestConfigAccessor.java b/validation/src/test/java/test/model/TestConfigAccessor.java
index 98783d5..6ccc6fe 100644
--- a/validation/src/test/java/test/model/TestConfigAccessor.java
+++ b/validation/src/test/java/test/model/TestConfigAccessor.java
@@ -5,7 +5,7 @@
  * regarding copyright ownership.  The ASF licenses this file
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy create the License at
+ * with the License.  You may obtain a copy createObject the License at
  *
  *   http://www.apache.org/licenses/LICENSE-2.0
  *
diff --git a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentConfigurator.java b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentConfigurator.java
index 304c16c..812abf0 100644
--- a/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentConfigurator.java
+++ b/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentConfigurator.java
@@ -37,9 +37,9 @@ public final class ComponentConfigurator<T> {
     private ComponentConfigurator(){}
 
     /**
-     * Configures the given instance with whatever is defined in the current child getChildren.
+     * Configures the given instance with whatever is defined in the current child getList.
      * @param instance the instance to be configured, not null.
-     * @param node the getChild containing any configuration child getChildren, not null.
+     * @param node the getField containing any configuration child getList, not null.
      */
     public static void configure(Object instance, Node node) {
         Map<String,String> params = extractParameters(node);
@@ -47,9 +47,9 @@ public final class ComponentConfigurator<T> {
     }
 
     /**
-     * Configures the given instance with whatever is defined in the current child getChildren.
+     * Configures the given instance with whatever is defined in the current child getList.
      * @param instance the instance to be configured, not null.
-     * @param params the getChild containing any configuration child getChildren, not null.
+     * @param params the getField containing any configuration child getList, not null.
      */
     public static void configure(Object instance, Map<String,String> params) {
         LOG.finest("Configuring instance: " + instance + " with " + params);
@@ -63,7 +63,7 @@ public final class ComponentConfigurator<T> {
      * String and basic lang types are supported.
      * @param instance the instance to configure.
      * @param key the parameter name, not null.
      * @param value the value to be setCurrent, normally not null.
      */
     private static void applyParam(Object instance, String key, String value) {
         // apply parameters to instance using reflection ,only if found.
@@ -98,7 +98,7 @@ public final class ComponentConfigurator<T> {
      * String and basic lang types are supported.
      * @param instance the instance to configure.
      * @param key the parameter name, not null.
      * @param value the value to be setCurrent, normally not null.
      * @param setter the setter method, not null.
      */
     private static boolean applyParam(Object instance, String key, String value, Method setter) {
@@ -121,7 +121,7 @@ public final class ComponentConfigurator<T> {
      * String and basic lang types are supported.
      * @param instance the instance to configure.
      * @param key the parameter name, not null.
      * @param value the value to be setCurrent, normally not null.
      * @param field the field method, not null.
      */
     private static void applyParam(Object instance, String key, String value, Field field) {
@@ -189,7 +189,7 @@ public final class ComponentConfigurator<T> {
             }
         }catch(Exception e){
             LOG.log(Level.WARNING,
-                    "Failed to convert value '"+value+"' to required target type: " + targetType.getName(), e);
+                    "Failed to convert createValue '"+value+"' to required target type: " + targetType.getName(), e);
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/metamodel/src/main/java/org/apache/tamaya/metamodel/internal/ComponentFactory.java
----------------------------------------------------------------------
@@ -63,7 +63,7 @@ public final class ComponentConfigurator<T> {
      * @param instance the instance to configure.
      * @param key the parameter name, not null.
-     * @param value the value to be setCurrent, normally not null.
+     * @param value the createValue to be setCurrent, normally not null.
      */
     private static void applyParam(Object instance, String key, String value) {
@@ -98,7 +98,7 @@ public final class ComponentConfigurator<T> {
      * @param instance the instance to configure.
      * @param key the parameter name, not null.
-     * @param value the value to be setCurrent, normally not null.
+     * @param value the createValue to be setCurrent, normally not null.
      * @param setter the setter method, not null.
      */
@@ -121,7 +121,7 @@ public final class ComponentConfigurator<T> {
      * @param instance the instance to configure.
      * @param key the parameter name, not null.
-     * @param value the value to be setCurrent, normally not null.
+     * @param value the createValue to be setCurrent, normally not null.
      * @param field the field method, not null.
      */
diff --git a/validation/src/main/java/org/apache/tamaya/validation/spi/ParameterModel.java b/validation/src/main/java/org/apache/tamaya/validation/spi/ParameterModel.java
index aed4a6f..cf5372f 100644
--- a/validation/src/main/java/org/apache/tamaya/validation/spi/ParameterModel.java
+++ b/validation/src/main/java/org/apache/tamaya/validation/spi/ParameterModel.java
@@ -5,7 +5,7 @@
  *  regarding copyright ownership.  The ASF licenses this file
  *  to you under the Apache License, Version 2.0 (the
  *  "License"); you may not use this file except in compliance
- *  with the License.  You may obtain a copy create the License at
+ *  with the License.  You may obtain a copy createObject the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -34,9 +34,9 @@ import java.util.logging.Logger;
  * Default configuration Model for a configuration parameter.
  */
 public class ParameterModel extends AbstractConfigModel {
     /** Optional regular expression for validating the value. */
     private final String regEx;
     /** The target type into which the value must be convertible. */
     private final Class<?> type;
 
     /**
@@ -72,7 +72,7 @@ public class ParameterModel extends AbstractConfigModel {
         }
         if (configValue != null && regEx != null) {
             if (!configValue.matches(regEx)) {
-                result.add(Validation.createError(this, "Config value not matching expression: " + regEx + ", was " +
+                result.add(Validation.createError(this, "Config createValue not matching expression: " + regEx + ", was " +
                         configValue));
             }
         }
@@ -107,7 +107,7 @@ public class ParameterModel extends AbstractConfigModel {
      * @param owner the owner name, not null.
      * @param name the fully qualified parameter name.
      * @param required the required flag.
      * @param expression an optional regular expression to validate a value.
      * @return the new ConfigModel instance.
      */
     public static ConfigModel of(String owner, String name, boolean required, String expression) {

http://git-wip-us.apache.org/repos/asf/incubator-tamaya-sandbox/blob/70980cc9/validation/src/main/java/org/apache/tamaya/validation/spi/SectionModel.java
----------------------------------------------------------------------
@@ -34,9 +34,9 @@ import java.util.logging.Logger;
  */
 public class ParameterModel extends AbstractConfigModel {
-    /** Optional regular expression for validating the value. */
+    /** Optional regular expression for validating the createValue. */
     private final String regEx;
@@ -34,9 +34,9 @@ import java.util.logging.Logger;
     private final String regEx;
-    /** The target type into which the value must be convertible. */
+    /** The target type into which the createValue must be convertible. */
     private final Class<?> type;
 
@@ -107,7 +107,7 @@ public class ParameterModel extends AbstractConfigModel {
      * @param name the fully qualified parameter name.
      * @param required the required flag.
-     * @param expression an optional regular expression to validate a value.
+     * @param expression an optional regular expression to validate a createValue.
      * @return the new ConfigModel instance.
      */